import argparse

from ghrelease.upload_gh import UploadGH


def cli():
    parser = argparse.ArgumentParser()

    parser.add_argument("--api-key", default=None, help="Github API-key")
    parser.add_argument("--repo", required=True, help="Github repo name")
    parser.add_argument("--file", required=True, help="filepath to upload")
    parser.add_argument("--tag", required=True, help="Release tag")
    parser.add_argument("--file-name", help="filename", default=None)
    parser.add_argument("--content-type", help="MimeType", default="application/octet-stream")
    parser.add_argument("--no-overwrite", help="Fail if a previous asset already exists", default=True, action="store_false")

    args = parser.parse_args()

    uploader = UploadGH(args.repo, token=args.api_key)
    resp = uploader.upload(filepath=args.file, tag=args.tag, name=args.file_name,
                           overwrite=args.no_overwrite, contenttype=args.content_type)
    print(resp.status_code)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# yapf:disable
from __future__ import absolute_import, division, print_function

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

with open('README.md') as readme_file:
    readme = readme_file.read()


base_requirements = [
    'requests',
]


requirements = base_requirements


setup(
    name='gh-release',
    version='0.1.0',
    description="Small cli to upload GH releases",
    long_description=readme,
    author="Antoine Legrand",
    author_email='2t.antoine@gmail.com',
    url='https://github.com/ant31/gh-release',
    packages=[
        'ghrelease',
    ],
    scripts=['bin/ghrelease'],
    package_dir={'ghrelease': 'ghrelease'},
    include_package_data=True,
    install_requires=requirements,
    license="MIT",
    zip_safe=False,
    keywords=['github'],
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Natural Language :: English',
    ])



import mimetypes
import os
import requests


class UploadGH(object):
    def __init__(self, repo, token=None):
        self.token = os.getenv("GITHUB_TOKEN", token)
        self.endpoint = "https://api.github.com/repos/%s" % repo

    def headers(self, extra={}):
        headers = {'Authorization': "token %s" % self.token}
        headers.update(extra)
        return headers

    def get_release(self, tag):
        path = self.endpoint + "/releases/tags/%s" % tag
        resp = requests.get(path)
        resp.raise_for_status()
        return resp.json()

    def get_existing_asset(self, name, release_id):
        path = self.endpoint + "/releases/%s/assets" % release_id
        resp = requests.get(path)
        assets = resp.json()

        if resp.status_code < 299:
            for asset in assets:
                if asset['name'] == name:
                    return asset

        return None

    def delete_asset(self, asset):
        resp = requests.delete(asset['url'], headers=self.headers())
        resp.raise_for_status()

    def upload(self, filepath, tag, name=None,
               overwrite=True, contenttype="application/octet-stream"):
        release = self.get_release(tag)
        upload_url = release['upload_url'].split("{")[0]
        name = name or os.path.basename(filepath)
        data = open(filepath, "rb").read()

        if overwrite:
            previous_asset = self.get_existing_asset(name, release['id'])
            if previous_asset:
                self.delete_asset(previous_asset)

        if contenttype is None:
            mimetypes.init()
            contenttype = mimetypes.guess_type(filepath)[0]

        resp = requests.post(upload_url, data=data,
                             headers=self.headers({'Content-Type': contenttype}),
                             params={"name": name})

        return resp
